@@ -3,6 +3,8 @@ import datetime as dt
 import rsa
 from cryptography.fernet import Fernet
 import pandas as pd
+import string
+from random import choice
 
 KEYS_RSA = rsa.newkeys(512)
 
@@ -10,6 +12,64 @@ class LIB:
     def __init__(self):
         pass
 
+    @staticmethod
+    def findchar(string: str, substring: str, ocorrencia: int, inicio: int = 0, fim: int = None):
+        if fim is None:
+            fim = len(string)
+        if substring is None:
+            return None
+        if string is None:
+            return None
+        if ocorrencia is None:
+            ocorrencia = 1
+        while True:
+            pass
+
+    @staticmethod
+    def build_key(size: int = 24,
+                  sep: str = "-",
+                  word_length: int = 4,
+                  lower_case: bool = True,
+                  upper_case: bool = True,
+                  digits: bool = True,
+                  hex_digits: bool = False,
+                  oct_digits: bool = False,
+                  special_chars: bool = False,
+                  printable_chars: bool = False,
+                  control_chars: bool = False
+                  ):
+        index = 1
+        key = ""
+        literal = ""
+        if lower_case:
+            literal = literal + string.ascii_lowercase
+        if upper_case:
+            literal = literal + string.ascii_uppercase
+        if digits:
+            literal = literal + string.digits
+        if hex_digits:
+            literal = literal + string.hexdigits
+        if oct_digits:
+            literal = literal + string.octdigits
+        if special_chars:
+            literal = literal + string.punctuation
+        if printable_chars:
+            literal = literal + string.printable
+        if control_chars:
+            literal = literal + string.whitespace
+        try:
+            for i in range(size):
+                letra = choice(literal)
+                if index == word_length and i < size - 1:
+                    key += letra + sep
+                    index = 1
+                else:
+                    key += letra
+                    index += 1
+        except Exception as error:
+            key = f"Impossivel gerar uma chave. Erro: {error}"
+        return key
+
     @staticmethod
     def hash(word: str, pattern: str = "md5"):
         pattern_list = ["md5", "sha1", "sha224", "sha256", "sha384", "sha512"]
@@ -118,20 +178,21 @@ class LIB:
         return value
 
     @staticmethod
-    def Crud(sql: str=None, values: list=None, conexao=None):
+    def Crud(sql: str = None, values: dict = None, conexao = None, commit: bool = True):
         msg, result, linhas_afetadas = None, [], 0
         try:
             if not isinstance(sql, str) or sql is None:
                 raise Exception(f"""Comando sql não foi definido {sql}""")
             if conexao is None:
                 raise Exception(f"""Conexão não foi informada {conexao}""")
-            if not isinstance(values, list) or dict is None:
+            if not isinstance(values, dict):
                 raise Exception(f"""Lista de valores não foi informada {values}""")
             cursor = conexao.cursor()
-            cursor.executemany(sql, values)
+            cursor.execute(sql, values)
             linhas_afetadas = cursor.rowcount
-            conexao.commit()
-            conexao.close()
+            cursor.close()
+            if commit:
+                conexao.commit()
             msg = f"""Comando SQL executado com sucesso!"""
         except Exception as error:
             msg = f"""Falha ao tentar executar o comando SQL! Erro: {error}"""
@@ -208,6 +269,16 @@ class LIB:
             result = error
         finally:
             return result
+
+    @staticmethod
+    def get_parametros_familia(df, value) -> pd.DataFrame:
+        result = None
+        try:
+            result = df.loc[df["familia"] == value]
+        except Exception as error:
+            result = error
+        finally:
+            return result
         
     @staticmethod
     def parametro_set(conexao, nom_parametro, val_parametro):
